browserutilities/downloadmgr/DownloadMgrUiLib/Inc/CUserInteractionsUtils.h
changeset 10 a359256acfc6
parent 0 dd21522fd290
child 25 0ed94ceaa377
--- a/browserutilities/downloadmgr/DownloadMgrUiLib/Inc/CUserInteractionsUtils.h	Fri Jul 03 15:54:40 2009 +0100
+++ b/browserutilities/downloadmgr/DownloadMgrUiLib/Inc/CUserInteractionsUtils.h	Thu Aug 27 07:44:59 2009 +0300
@@ -326,10 +326,10 @@
         TBool IsNetworkPdCompatibleL() const;
 
         /**
         * Sends a message to the PD applications (MP, VP )
         * before browser exits
         */
-        void SendMsgTerminateToPdAppsL();
+        void SendMsgTerminateToPdAppsL( TBool aProgressiveDownloadLaunched );
 
 		/**
 		* Checks if the WLAN is available
@@ -326,10 +326,10 @@
 
         /**
-        * Sends a message to the PD applications (MP, VP )
-        * before browser exits
+        * Sends a message to the PD applications (MP, VP ) before browser exits
+        * @param aProgressiveDownloadLaunched Progressive Play Launched or not 
         */